0.2.0 2015-01-27
----------------

- Add connection configuration.

- Fix click in search results.

- Restructure JS source files.

- Various UI improvements/fixes.


0.1.3 2015-01-27
----------------

- Bump version due to PyPi issues.


0.1.2 2015-01-27
----------------

- Fix play/pause toggle button issues.


0.1.1 2015-01-26
----------------

- Fix root search.

- Workaround for play/pause toggle button issues.

- Workaround for reconnect issues.


0.1.0 2015-01-26
----------------

- Initial release.
